#
# spec file for package cinnamon-menus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define typelib typelib-1_0-CMenu-3_0
%define soname  libcinnamon-menu-3
%define sover   0
Name:           cinnamon-menus
Version:        6.0.0
Release:        1.1
Summary:        A menu system for the Cinnamon Desktop
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/linuxmint/cinnamon-menus
Source:         https://github.com/linuxmint/cinnamon-menus/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)

%description
cinnamon-menus is an implementation of the draft "Desktop Menu
Specification" from freedesktop.org. This package also contains
the Cinnamon menu layout configuration files, .directory files and
assorted menu related utility programs, Python bindings, and a
simple menu editor.

%package -n %{soname}-%{sover}
Summary:        A menu system for the Cinnamon desktop environment
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{soname}-%{sover}
cinnamon-menus is an implementation of the draft "Desktop Menu
Specification" from freedesktop.org. This package also contains
the Cinnamon menu layout configuration files, .directory files and
assorted menu related utility programs, Python bindings, and a
simple menu editor.

%package -n %{typelib}
Summary:        Libcinnamon-menu API -- Introspection bindings
# typelib-1_0-CinnamonMenu-3_0 was last used in openSUSE Leap 42.2.
Group:          System/Libraries
Provides:       typelib-1_0-CinnamonMenu-3_0 = %{version}
Obsoletes:      typelib-1_0-CinnamonMenu-3_0 < %{version}

%description -n %{typelib}
cinnamon-menus is an implementation of the draft "Desktop Menu
Specification" from freedesktop.org. This package also contains
the Cinnamon menu layout configuration files, .directory files and
assorted menu related utility programs, Python bindings, and a
simple menu editor.

This package provides the GObject Introspection bindings for
cinnamon-menus.

%package -n %{soname}-devel
Summary:        Libraries and development headers for cinnamon-menus
Group:          Development/Libraries/Other
Requires:       %{soname}-%{sover} = %{version}
Requires:       %{typelib} = %{version}

%description -n %{soname}-devel
This package provides the necessary development libraries for
writing applications that use the Cinnamon menu system.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname}-%{sover} -p /sbin/ldconfig
%postun -n %{soname}-%{sover} -p /sbin/ldconfig

%files -n %{soname}-%{sover}
%license COPYING*
%doc AUTHORS README debian/changelog
%{_libdir}/%{soname}.so.%{sover}*

%files -n %{soname}-devel
%{_includedir}/%{name}-3.0/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/libcinnamon-menu-3.0.pc
%{_datadir}/gir-1.0/CMenu-3.0.gir

%files -n %{typelib}
%{_libdir}/girepository-1.0/CMenu-3.0.typelib

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * Fix meson.build deprecations up to 0.56.0
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- update to 5.8.0:
  * github workflow: Add optional ssh session.
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 5.6.0:
  * Use github instead of circleci.
  * Restore and update debian/ symbols file.
  * update packaging (#53)
* Thu May 27 2021 andy great <andythe_great@pm.me>
- Update to version 5.0.0.
  * No changelog.
* Thu Jan 14 2021 andy great <andythe_great@pm.me>
- Update to version 4.8.2.
  * Fix loading of desktop files in subdirectories
* Sat Dec  5 2020 andy great <andythe_great@pm.me>
- Update to version 4.8.1.
  * Fix handling of malformed desktop files.
  * Improve integration of flatpak apps.
* Fri Sep 18 2020 andy great <andythe_great@pm.me>
- Update to version 4.6.1.
  * gmenu-tree.c: Return a basename if no appinfo is available when
    sorting.
* Wed Jun 10 2020 andy great <andythe_great@pm.me>
- Update to version 4.6.0.
  * Version bump with no change.
* Mon Mar 16 2020 Marguerite Su <i@marguerite.su>
- update version 4.4.0
  * version bump with no change
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 4.2.0:
  * Switch to modern realpath() (#20)
  * Port to meson (#21)
  * Update for meson changes and also adapt for cinnamon (#23)
  * Build: fix the build options (#22)
  * Add devhelp docs to cinnamon menus for easier reference (#24)
  * Build: Set enable_debug to false
  * Add option to disable docs (#25)
  * Cleanup (#26)
  * Meson simplification (#27)
* Fri Mar 15 2019 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 4.0.0:
  * CI: Remove Mint 18
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * entry-directories.c: Restore retry handling to state prior to
    commit 7516e8d.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * Check for a valid GDesktopAppInfo before calling
    GDesktopAppInfo methods. Fix retry handling to only apply to
    new entries. Use g_timeout_add instead of g_idle_add for change
    signal accumulation.
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 3.8.0:
  * No changelog available.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.0:
  * Memory leak fixes.
  * entry-directories: Fix unref.
  * entry-directories: Don't modify a list while iterating it.
  * entry-directories: Protect event handling for directories.
  * libmenu: Remove support for legacy-dirs.
  * entry-directories: Only log about invalidations if it was
    handled.
* Thu May  4 2017 sor.alexei@meowr.ru
- Update to version 3.4.0:
  * Remove autogenerated files and remove the aclocal command from
    autogen.sh.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * Drop gtkdocize invocation.
- Rename typelib-1_0-CinnamonMenu-3_0 to typelib-1_0-CMenu-3_0 to
  match the actual typelib name.
* Wed Jun  1 2016 sor.alexei@meowr.ru
- Update to version 3.0.2:
  * Go back to loading .desktop files as GDesktopAppInfo – this
    is the only way g_desktop_app_info_get_filename() will work
    properly.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * entry-directories.c: Monitor mimeinfo.cache file and
    re-attempt failed .desktop files when it changes (which is
    usually just after the .desktop file is added, causing loading
    to fail due to unavailable GAppInfo).
  * desktop-entries.c: Refactor to eliminate double-loading of
    .desktop file. Use g_key_file_load_from_file, followed by
    g_desktop_app_info_new_from_keyfile.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * configure.ac: Drop an obsolete macro.
* Tue Oct 20 2015 sor.alexei@meowr.ru
- Update to 2.8.0.
- Fix license.
* Mon Aug 10 2015 i@marguerite.su
- add baselibs.conf
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.0
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.2
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * upstream just bump its version
* Fri Apr 18 2014 i@marguerite.su
- initial version 2.2.0
